#!/bin/sh
#
# Script to generate xdelta diffs for KDE and KDE i18n.
# Requires the source packages to be in $OLDDIR and $NEWDIR
# The resulting diffs will end up in $DSTDIR.
# $WRKDIR is used as work area
#

OLDVER=3.1rc5
NEWVER=3.1rc6

OLDDIR=/home/ftp/pub/kde/unstable/kde-3.1-rc5/src
NEWDIR=/home/ftp/pub/kde/unstable/kde-3.1-rc6/src

WRKDIR="$HOME/KDE-Delta-work"
DSTDIR="$HOME/KDE-Delta"

PACKAGES="kdeaddons kdeadmin kdeartwork kdebase kdebindings kdeedu kdegames kdegraphics \
          kdelibs kdemultimedia kdenetwork kdepim kdesdk kdetoys kdeutils"

# kde-i18n
I18N_PACKAGES="af ar bg bs ca cs da de el en_GB eo es et fa fi fr he hu it ja lt mt nb nl \
               nn nso pl pt pt_BR ro ru sk sl sr sv ta th tr uk ven vi xh zh_CN zh_TW zu"

mkdir -p $WRKDIR
mkdir -p $DSTDIR
mkdir -p $DSTDIR/kde-i18n

        # kde sources
cd $WRKDIR
for package in $PACKAGES; do
        echo -e "Decompressing $package-$OLDVER"
        cp $OLDDIR/$package-$OLDVER.tar.bz2 .
        bunzip2 $package-$OLDVER.tar.bz2
        echo -e "Decompressing $package-$NEWVER"
        cp $NEWDIR/$package-$NEWVER.tar.bz2 .
        bunzip2 $package-$NEWVER.tar.bz2
        
        echo -e "Diffing $package"
        xdelta delta -9 $package-$OLDVER.tar $package-$NEWVER.tar $DSTDIR/patch-$package-$OLDVER-$NEWVER
        
        rm $package-$OLDVER.tar
        rm $package-$NEWVER.tar
done

        # i18n
cd $WRKDIR
for package in $I18N_PACKAGES; do
        package=kde-i18n-$package
        
        echo -e "Decompressing $package-$OLDVER"
        cp $OLDDIR/kde-i18n/$package-$OLDVER.tar.bz2 .
        bunzip2 $package-$OLDVER.tar.bz2
        echo -e "Decompressing $package-$NEWVER"
        cp $NEWDIR/kde-i18n/$package-$NEWVER.tar.bz2 .
        bunzip2 $package-$NEWVER.tar.bz2
        echo -e "Diffing $package"
        xdelta delta -9 $package-$OLDVER.tar $package-$NEWVER.tar	 $DSTDIR/kde-i18n/patch-$package-$OLDVER-$NEWVER
        
        rm $package-$OLDVER.tar
        rm $package-$NEWVER.tar
done
